summaryrefslogtreecommitdiff
path: root/src/include/btree.h
diff options
context:
space:
mode:
authorKeith Bostic <keith@wiredtiger.com>2015-02-02 17:15:29 -0500
committerKeith Bostic <keith@wiredtiger.com>2015-02-02 17:15:29 -0500
commitebce95976e2376e377841d42c223f97a14f39db8 (patch)
treeafcea0f7135b6652b6f7a53091179a3af42c372c /src/include/btree.h
parent784eeeeb62123d7e321dd61fbb9bffc3873cef04 (diff)
parent8545c4b3b7f5ed306215c82f1ad1cbe3664f0c50 (diff)
downloadmongo-ebce95976e2376e377841d42c223f97a14f39db8.tar.gz
Merge branch 'develop' into accounting-keith
Diffstat (limited to 'src/include/btree.h')
-rw-r--r--src/include/btree.h23
1 files changed, 15 insertions, 8 deletions
diff --git a/src/include/btree.h b/src/include/btree.h
index fa01dd5edc2..dd3acf6940d 100644
--- a/src/include/btree.h
+++ b/src/include/btree.h
@@ -98,14 +98,21 @@ struct __wt_btree {
CKSUM_UNCOMPRESSED=3 /* Uncompressed blocks only */
} checksum; /* Checksum configuration */
- u_int dictionary; /* Reconcile: dictionary slots */
- int internal_key_truncate; /* Reconcile: internal key truncate */
- int maximum_depth; /* Reconcile: maximum tree depth */
- int prefix_compression; /* Reconcile: prefix compression */
- u_int prefix_compression_min; /* Reconcile: prefix compression min */
- int split_pct; /* Reconcile: split page percent */
- WT_COMPRESSOR *compressor; /* Reconcile: page compressor */
- WT_RWLOCK *ovfl_lock; /* Reconcile: overflow lock */
+ /*
+ * Reconciliation...
+ */
+ u_int dictionary; /* Dictionary slots */
+ int internal_key_truncate; /* Internal key truncate */
+ int maximum_depth; /* Maximum tree depth */
+ int prefix_compression; /* Prefix compression */
+ u_int prefix_compression_min; /* Prefix compression min */
+#define WT_SPLIT_DEEPEN_MIN_CHILD_DEF 10000
+ u_int split_deepen_min_child; /* Minimum entries to deepen tree */
+#define WT_SPLIT_DEEPEN_PER_CHILD_DEF 100
+ u_int split_deepen_per_child; /* Entries per child when deepened */
+ int split_pct; /* Split page percent */
+ WT_COMPRESSOR *compressor; /* Page compressor */
+ WT_RWLOCK *ovfl_lock; /* Overflow lock */
uint64_t last_recno; /* Column-store last record number */